@@ -93,12 +93,17 @@ class Recipe(zc.recipe.egg.Eggs):
     def install(self):
         """Creates the part."""
 
-        options = self.options
-        self.install_mongodb()
-        return ()
+        return self.install_mongodb()
 
     def update(self):
         """Updates the part."""
 
-        options = self.options
-        return ()
+        bindir = self.buildout['buildout']['bin-directory']
+        mongod = os.path.join(bindir, 'mongod')
+        if os.path.isfile(mongod):
+            os.remove(mongod)
+        dst = os.path.join(self.buildout['buildout']['parts-directory'],
+                           self.name)
+        if os.path.isdir(dst):
+            shutil.rmtree(dst)
+        return self.install_mongodb()
